/*
 * backup_conf_x.h: domain backup XML processing
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library.  If not, see
 * <http://www.gnu.org/licenses/>.
 */

#pragma once

# include "internal.h"
# include "domain_conf.h"

typedef struct _virDomainBlockSnapshotDiskDef virDomainBlockSnapshotDiskDef;
struct _virDomainBlockSnapshotDiskDef {
    char *name;
    virStorageSource *fleece;
    int idx;
};

typedef struct _virDomainBlockSnapshotDef virDomainBlockSnapshotDef;
struct _virDomainBlockSnapshotDef {
    char *name;
    size_t ndisks;
    virDomainBlockSnapshotDiskDef *disks;
    int conn_id; /* 0 if client don't want autodeleting */
    bool autodelete;
};

virDomainBlockSnapshotDef *
virDomainBlockSnapshotDefParse(xmlNode *node, xmlXPathContext *ctxt);

virDomainBlockSnapshotDef *
virDomainBlockSnapshotDefParseString(const char *xmlStr,
                                     virCaps *caps,
                                     virDomainXMLOption *xmlopt,
                                     unsigned int flags);

virDomainBlockSnapshotDef *
virDomainBlockSnapshotDefParseNode(xmlDoc *xml,
                                   xmlNode *root,
                                   virCaps *caps,
                                   virDomainXMLOption *xmlopt,
                                   unsigned int flags);

void
virDomainBlockSnapshotDefFormat(virBuffer *buf,
                                const virDomainBlockSnapshotDef *def,
                                bool shortname);
char *virDomainBlockSnapshotDefFormatString(const virDomainBlockSnapshotDef *def);

void virDomainBlockSnapshotDefFree(virDomainBlockSnapshotDef *def);

int
virDomainBlockSnapshotDefResolveDisks(virDomainBlockSnapshotDef *def,
                                      virDomainDef *vmdef);

virDomainDiskDef *
virDomainBlockSnapshotDomainDisk(virDomainObj *vm,
                                 virDomainBlockSnapshotDef *def,
                                 int i);

void
virDomainBlockSnapshotDefFreeEntry(void *value);
