/*
 * domain_exec.h: helper for executing commands in guest
 *
 * Copyright (C) 2022 Virtuozzo, Inc.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library.  If not, see
 * <http://www.gnu.org/licenses/>.
 */

#pragma once

#include "internal.h"

#include "virconftypes.h"

typedef int (*virDomainExecuteCommandSpawnCallback)(virConnectPtr conn,
                                                    virDomainObj *obj,
                                                    const char *cmd,
                                                    const char **args,
                                                    unsigned int nargs,
                                                    const char **envs,
                                                    unsigned int nenvs,
                                                    virStreamPtr in,
                                                    virStreamPtr out,
                                                    virStreamPtr err,
                                                    unsigned int flags,
                                                    void *opaque);

typedef int (*virDomainExecuteCommandStatusCallback)(virDomainObj *obj,
                                                     int pid_value,
                                                     virDomainCommandXStatusPtr status,
                                                     void *opaque);

typedef int (*virDomainExecuteCommandTerminateCallback)(virDomainObj *obj,
                                                        int pid_value,
                                                        void *opaque);

typedef struct _virDomainExecuteCommandCallbacks virDomainExecuteCommandCallbacks;
struct _virDomainExecuteCommandCallbacks {
    virDomainExecuteCommandSpawnCallback spawn;
    virDomainExecuteCommandStatusCallback status;
    virDomainExecuteCommandTerminateCallback terminate;
};

int
virDomainExecuteCommand(virConnectPtr conn,
                        virDomainObj *obj,
                        const char *cmd,
                        const char **args,
                        unsigned int nargs,
                        char **output,
                        virDomainExecuteCommandCallbacks *callbacks,
                        void *opaque);
